/// <reference types="node" />
import AsyncLock from 'async-lock';
import WebSocket from 'ws';
import { IncomingMessage as HTTPIncomingMessage } from 'http';
import Document from './Document';
declare class Connection {
    connection: WebSocket;
    context: any;
    document: Document;
    pingInterval: NodeJS.Timeout;
    pongReceived: boolean;
    request: HTTPIncomingMessage;
    timeout: number;
    callbacks: any;
    socketId: string;
    lock: AsyncLock;
    readOnly: Boolean;
    /**
     * Constructor.
     */
    constructor(connection: WebSocket, request: HTTPIncomingMessage, document: Document, timeout: number, socketId: string, context: any, readOnly?: boolean);
    /**
     * Set a callback that will be triggered when the connection is closed
     */
    onClose(callback: (document: Document) => void): Connection;
    /**
     * Send the given message
     */
    send(message: any): void;
    /**
     * Close the connection
     */
    close(): void;
    /**
     * Check if pong was received and close the connection otherwise
     * @private
     */
    private check;
    /**
     * Send first sync step
     * @private
     */
    private sendFirstSyncStep;
    /**
     * Handle an incoming message
     * @private
     */
    private handleMessage;
    /**
     * Get the underlying connection instance
     */
    get instance(): WebSocket;
}
export default Connection;
