/// <reference types="node" />
import WebSocket from 'ws';
import { IncomingMessage, Server as HTTPServer } from 'http';
import { Configuration } from './types';
export declare const defaultConfiguration: {
    port: number;
    timeout: number;
};
/**
 * Hocuspocus yjs websocket server
 */
export declare class Hocuspocus {
    configuration: Configuration;
    documents: Map<any, any>;
    httpServer?: HTTPServer;
    websocketServer?: WebSocket.Server;
    /**
     * Configure the server
     */
    configure(configuration: Partial<Configuration>): Hocuspocus;
    /**
     * Start the server
     */
    listen(): Promise<void>;
    /**
     * Destroy the server
     */
    destroy(): Promise<any>;
    /**
     * Handle the incoming websocket connection
     */
    handleConnection(incoming: WebSocket, request: IncomingMessage, documentName: string, context?: any): void;
    /**
     * Handle update of the given document
     * @private
     */
    private handleDocumentUpdate;
    /**
     * Create a new document by the given request
     * @private
     */
    private createDocument;
    /**
     * Create a new connection by the given request and document
     * @private
     */
    private createConnection;
    /**
     * Run the given hook on all configured extensions
     * Runs the given callback after each hook
     * @private
     */
    private hooks;
    /**
     * Get parameters by the given request
     * @private
     */
    private static getParameters;
    /**
     * Get document name by the given request
     * @private
     */
    private static getDocumentName;
}
export declare const Server: Hocuspocus;
