/// <reference types="node" />
import { Extension, onChangePayload, onConfigurePayload, onConnectPayload, onCreateDocumentPayload, onDestroyPayload, onDisconnectPayload, onListenPayload, onRequestPayload, onUpgradePayload } from '@hocuspocus/server';
import { Doc } from 'yjs';
import { Transformer } from '@hocuspocus/transformer';
import { AxiosResponse } from 'axios';
import Timeout = NodeJS.Timeout;
export declare enum Events {
    onChange = "change",
    onConnect = "connect",
    onCreate = "create",
    onDisconnect = "disconnect"
}
export interface Configuration {
    debounce: number | false | null;
    debounceMaxWait: number;
    secret: string;
    transformer: Transformer | {
        toYdoc: (document: any) => Doc;
        fromYdoc: (document: Doc) => any;
    };
    url: string;
    events: Array<Events>;
}
export declare class Webhook implements Extension {
    configuration: Configuration;
    debounced: Map<string, {
        timeout: Timeout;
        start: number;
    }>;
    /**
     * Constructor
     */
    constructor(configuration?: Partial<Configuration>);
    /**
     * Create a signature for the response body
     */
    createSignature(body: string): string;
    /**
     * debounce the given function, using the given identifier
     */
    debounce(id: string, func: Function): void;
    /**
     * Send a request to the given url containing the given data
     */
    sendRequest(event: Events, payload: any): Promise<AxiosResponse<any>>;
    /**
     * onChange hook
     */
    onChange(data: onChangePayload): Promise<void>;
    /**
     * onCreateDocument hook
     */
    onCreateDocument(data: onCreateDocumentPayload): Promise<void>;
    /**
     * onConnect hook
     */
    onConnect(data: onConnectPayload): Promise<any>;
    onDisconnect(data: onDisconnectPayload): Promise<void>;
    onUpgrade(data: onUpgradePayload): Promise<void>;
    onRequest(data: onRequestPayload): Promise<void>;
    onListen(data: onListenPayload): Promise<void>;
    onDestroy(data: onDestroyPayload): Promise<void>;
    onConfigure(data: onConfigurePayload): Promise<void>;
}
